[![pypi](https://img.shields.io/pypi/v/soraxas-toolbox)](https://pypi.org/project/soraxas-toolbox/)
[![python-version](https://img.shields.io/pypi/pyversions/soraxas-toolbox)](https://pypi.org/project/soraxas-toolbox)
[![Master Update](https://img.shields.io/github/last-commit/soraxas/python-soraxas_toolbox/master.svg)](https://github.com/soraxas/python-soraxas_toolbox/commits/master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/github/license/soraxas/python-soraxas_toolbox.svg)](https://github.com/soraxas/python-soraxas_toolbox/blob/master/LICENSE)

# Python toolbox

A simple toolbox for various scenario. Documentation will unlikely be provided here.

Use without any warranty :)

Cheers
